CreateServiceRequest

Struct CreateServiceRequest 

pub struct CreateServiceRequest {
    pub enabled: bool,
    pub domain: Option<Vec<String>>,
    pub prefix: String,
    pub container_image: String,
    pub container_image_version: Option<String>,
    pub container_port: Option<i32>,
    pub container_pull_user: Option<String>,
    pub container_pull_pwd: Option<String>,
    pub env_variables: Option<HashMap<String, CreateJobRequestEnvVariablesValue>>,
    pub rewrite: Option<Box<ServiceRewrite>>,
    pub login: Option<Box<ServiceLogin>>,
    pub mounts: Option<Vec<VolumeMount>>,
}

Fields

enabled: bool

whether this service is active and should be propagated to ingress

domain: Option<Vec<String>>

by default this property is empty and represents that all verified domains will be added. I a domain is added through a service, this service will only be served through that domain, und new domain als also no longer added automatically.

prefix: Stringcontainer_image: Stringcontainer_image_version: Option<String>

the version of the container image; either empty string to reset or a sha256 digest in the form of "sha256:digest"

container_port: Option<i32>

Optional port to expose externally; when omitted the first open container port is exposed automatically.

container_pull_user: Option<String>container_pull_pwd: Option<String>env_variables: Option<HashMap<String, CreateJobRequestEnvVariablesValue>>rewrite: Option<Box<ServiceRewrite>>login: Option<Box<ServiceLogin>>mounts: Option<Vec<VolumeMount>>

Implementations

Source

impl CreateServiceRequest

pub fn new( enabled: bool, prefix: String, container_image: String, ) -> CreateServiceRequest