pub struct UpdateServiceRequestLogin {
pub provider_name: String,
}Expand description
UpdateServiceRequestLogin : a login can only be added, to remove the login functionality, either set the providerName to an empty string or recreate the service without the login property
Fields
provider_name: StringImplementations
Sourceimpl UpdateServiceRequestLogin
impl UpdateServiceRequestLogin
Sourcepub fn new(provider_name: String) -> UpdateServiceRequestLogin
pub fn new(provider_name: String) -> UpdateServiceRequestLogin
a login can only be added, to remove the login functionality, either set the providerName to an empty string or recreate the service without the login property